@@ -5,10 +5,11 @@ describe 'ec2api::api', type: :class do
   on_supported_os(supported_os: OSDefaults.get_supported_os).each do |os, facts|
     context "on #{os}" do
 
-      let(:facts) { facts.merge! @default_facts }
+      let(:facts) do
+        facts.merge!(OSDefaults.get_facts())
+      end
 
       config_items = %w(
-        DEFAULT/keystone_url
         DEFAULT/keystone_ec2_tokens_url
         DEFAULT/ec2_timestamp_expiry
         DEFAULT/ec2api_listen
